cls

## Chapter 5 Setup
## by Dan Holme
##
## The script is provided AS-IS
## with no warranty expressed or implied
## Use only in a test environment, at your own risk
##
## (c) 2010 Intelliem, Inc.
##
## This script may be used only as directed by the
## 70-667 Training Kit
## published by Microsoft Press.
## The script may be used only in conjunction with 
## study of the Training Kit
## by the purchaser of the Training Kit
##
## Contact dan.holme@intelliem.com for more information
##

Write-Host "Please wait while the script prepares for Chapter 5, Lesson 1"
Write-Host "============================================================="

Write-Host "Registering the managed account CONTOSO\SP_WebApps"
$Credential = New-Object System.Management.Automation.PSCredential "CONTOSO\SP_WebApps",(ConvertTo-SecureString "Pa`$`$w0rd" -AsPlainText -Force)
New-SPManagedAccount $credential | Select UserName

Write-Host
Write-Host "Creating a Web application: Intranet"
New-SPWebApplication -Name "Contoso Intranet" -Port 80 -HostHeader "intranet.contoso.com" -URL "http://intranet.contoso.com:80" -ApplicationPool "SharePoint Web Applications" -ApplicationPoolAccount "CONTOSO\SP_WebApps" -DatabaseName "SharePoint_Content_Intranet" | Select URL
Write-Host "Creating a site collection: http://intranet.contoso.com/"
New-SPSite -Url "http://intranet.contoso.com/" -Name "Contoso Intranet" Description "Contoso Published Intranet Content" -Template "STS#0" -OwnerAlias "CONTOSO\SP_Admin" OwnerEmail "SP_Admin@contoso.com" | Select Name

Write-Host "Creating a content database: SharePoint"
New-SPContentDatabase -Name SharePoint_Content_SharePoint -WebApplication http://intranet.contoso.com | Select Name
Write-Host "Creating a site collection: http://intranet.contoso.com/sites/SharePoint"
New-SPSite -Url "http://intranet.contoso.com/sites/SharePoint" -Name "Contoso SharePoint Service" Description "Contoso SharePoint Service" -Template "STS#0" -OwnerAlias "CONTOSO\SP_Admin" OwnerEmail "SP_Admin@contoso.com" ContentDatabase "SharePoint_Content_SharePoint" | Select Name

Write-Host "Creating a DNS host record for intranet.contoso.com"
Write-Host "and teams.contoso.com at 10.0.0.21"
Write-Host "If an error appears that indicates the record already exists, "
Write-Host "you can ignore the error."

dnscmd contoso-dc.contoso.com /RecordAdd contoso.com intranet A 10.0.0.21
dnscmd contoso-dc.contoso.com /RecordAdd contoso.com teams A 10.0.0.21

Write-Host
Write-Host "Creating a web application: Teams"

New-SPWebApplication -Name "Contoso Teams" -Port 80 -HostHeader "teams.contoso.com" -URL "http://teams.contoso.com:80" -ApplicationPool "SharePoint Web Applications" -DatabaseName "SharePoint_Content_Teams" | Select URL

Write-Host "Creating a site collection: http://teams.contoso.com/"
New-SPSite -Url "http://teams.contoso.com/" -Name "Contoso Departments, Teams, and Projects" Description "Collaboration sites for Contoso departments, teams, and projects" -Template "STS#0" -OwnerAlias "CONTOSO\SP_Admin" OwnerEmail "SP_Admin@contoso.com" | Select Name

Write-Host "Create depts managed path."
Remove-SPManagedPath "sites" -WebApplication "http://teams.contoso.com" -Confirm:$false
New-SPManagedPath "depts" -WebApplication "http://teams.contoso.com"

Write-Host "Enable self-service site creation on Teams"
$webapp = Get-SPWebApplication "http://teams.contoso.com"
$webapp.SelfServiceSiteCreationEnabled = $true
$webapp.RequireContactForSelfServiceSiteCreation = $true
$webapp.Update()
Write-Host

$url = "http://teams.contoso.com/depts/IT"
$ContentDatabase = "SharePoint_Content_Teams_IT" 
$WebsiteName = "Information Technology"
$WebsiteDesc = "Information Technology department team site"
$Template = "STS#0" 
$PrimaryLogin = "CONTOSO\SP_Admin"
$PrimaryDisplay = "SharePoint Administrator and Setup User"
$PrimaryEmail = "SP_Admin@contoso.com" 
$SecondaryLogin = "CONTOSO\AprilM"
$SecondaryDisplay = "Meyer, April"
$SecondaryEmail = "April.Meyer@contoso.com"
$MembersGroup = "$WebsiteName Members"
$ViewersGroup = "Viewers"

Write-Host "Creating a content database: $ContentDatabase"
New-SPContentDatabase -Name $ContentDatabase -WebApplication http://teams.contoso.com | Select Name
Write-Host "Creating a site collection: $WebsiteName"
New-SPSite -Url $url ContentDatabase $ContentDatabase -Name $WebsiteName Description $WebsiteDesc  -Template $Template -OwnerAlias $PrimaryLogin OwnerEmail $PrimaryEmail -SecondaryOwnerAlias $SecondaryLogin -SecondaryEmail $SecondaryEmail  | Select Name
$web = Get-SPWeb $url
$web.CreateDefaultAssociatedGroups($PrimaryLogin,"","")
$PrimaryAdmin = Get-SPUser $PrimaryLogin -Web $url
$PrimaryAdmin.Name = $PrimaryDisplay
$PrimaryAdmin.Update()
$Members = ($web.SiteGroups | Where {$_.Name -eq $MembersGroup} )
$Members.AddUser($PrimaryAdmin)
$Viewers = ($web.SiteGroups | Where {$_.Name -eq $ViewersGroup } )
$Viewers.AddUser($PrimaryAdmin)
$SecondaryAdmin = Get-SPUser $SecondaryLogin -Web $url
$SecondaryAdmin.Name = $SecondaryDisplay
$SecondaryAdmin.Update()
$web.Dispose()

$url = "http://teams.contoso.com/depts/Finance"
$ContentDatabase = "SharePoint_Content_Teams_Finance" 
$WebsiteName = "Finance"
$WebsiteDesc = "Finance department team site"
$Template = "STS#0" 
$PrimaryLogin = "CONTOSO\SP_Admin"
$PrimaryDisplay = "SharePoint Administrator and Setup User"
$PrimaryEmail = "SP_Admin@contoso.com" 
$MembersGroup = "$WebsiteName Members"
$ViewersGroup = "Viewers"

Write-Host "Creating a content database: $ContentDatabase"
New-SPContentDatabase -Name $ContentDatabase -WebApplication http://teams.contoso.com | Select Name
Write-Host "Creating a site collection: $WebsiteName"
New-SPSite -Url $url ContentDatabase $ContentDatabase -Name $WebsiteName Description $WebsiteDesc  -Template $Template -OwnerAlias $PrimaryLogin OwnerEmail $PrimaryEmail -SecondaryOwnerAlias $SecondaryLogin -SecondaryEmail $SecondaryEmail  | Select Name
$web = Get-SPWeb $url
$web.CreateDefaultAssociatedGroups($PrimaryLogin,"","")
$PrimaryAdmin = Get-SPUser $PrimaryLogin -Web $url
$PrimaryAdmin.Name = $PrimaryDisplay
$PrimaryAdmin.Update()
$Members = ($web.SiteGroups | Where {$_.Name -eq $MembersGroup} )
$Members.AddUser($PrimaryAdmin)
$Viewers = ($web.SiteGroups | Where {$_.Name -eq $ViewersGroup } )
$Viewers.AddUser($PrimaryAdmin)
$web.Dispose()

$url = "http://teams.contoso.com/depts/Marketing"
$ContentDatabase = "SharePoint_Content_Teams_Marketing" 
$WebsiteName = "Marketing"
$WebsiteDesc = "Marketing department team site"
$Template = "STS#0" 
$PrimaryLogin = "CONTOSO\SP_Admin"
$PrimaryDisplay = "SharePoint Administrator and Setup User"
$PrimaryEmail = "SP_Admin@contoso.com" 
$MembersGroup = "$WebsiteName Members"
$ViewersGroup = "Viewers"

Write-Host "Creating a content database: $ContentDatabase"
New-SPContentDatabase -Name $ContentDatabase -WebApplication http://teams.contoso.com | Select Name
Write-Host "Creating a site collection: $WebsiteName"
New-SPSite -Url $url ContentDatabase $ContentDatabase -Name $WebsiteName Description $WebsiteDesc  -Template $Template -OwnerAlias $PrimaryLogin OwnerEmail $PrimaryEmail -SecondaryOwnerAlias $SecondaryLogin -SecondaryEmail $SecondaryEmail  | Select Name
$web = Get-SPWeb $url
$web.CreateDefaultAssociatedGroups($PrimaryLogin,"","")
$PrimaryAdmin = Get-SPUser $PrimaryLogin -Web $url
$PrimaryAdmin.Name = $PrimaryDisplay
$PrimaryAdmin.Update()
$Members = ($web.SiteGroups | Where {$_.Name -eq $MembersGroup} )
$Members.AddUser($PrimaryAdmin)
$Viewers = ($web.SiteGroups | Where {$_.Name -eq $ViewersGroup } )
$Viewers.AddUser($PrimaryAdmin)
$web.Dispose()

$url = "http://teams.contoso.com/depts/Sales"
$ContentDatabase = "SharePoint_Content_Teams_Sales" 
$WebsiteName = "Sales"
$WebsiteDesc = "Sales department team site"
$Template = "STS#0" 
$PrimaryLogin = "CONTOSO\SP_Admin"
$PrimaryDisplay = "SharePoint Administrator and Setup User"
$PrimaryEmail = "SP_Admin@contoso.com" 
$MembersGroup = "$WebsiteName Members"
$ViewersGroup = "Viewers"

Write-Host "Creating a content database: $ContentDatabase"
New-SPContentDatabase -Name $ContentDatabase -WebApplication http://teams.contoso.com | Select Name
Write-Host "Creating a site collection: $WebsiteName"
New-SPSite -Url $url ContentDatabase $ContentDatabase -Name $WebsiteName Description $WebsiteDesc  -Template $Template -OwnerAlias $PrimaryLogin OwnerEmail $PrimaryEmail -SecondaryOwnerAlias $SecondaryLogin -SecondaryEmail $SecondaryEmail  | Select Name
$web = Get-SPWeb $url
$web.CreateDefaultAssociatedGroups($PrimaryLogin,"","")
$PrimaryAdmin = Get-SPUser $PrimaryLogin -Web $url
$PrimaryAdmin.Name = $PrimaryDisplay
$PrimaryAdmin.Update()
$Members = ($web.SiteGroups | Where {$_.Name -eq $MembersGroup} )
$Members.AddUser($PrimaryAdmin)
$Viewers = ($web.SiteGroups | Where {$_.Name -eq $ViewersGroup } )
$Viewers.AddUser($PrimaryAdmin)
$web.Dispose()

Write-Host
Write-Host "Finished"
